import Icon, {
  GlobalOutlined,
  IconProvider,
  MailOutlined,
  PhoneOutlined,
} from '@ant-design/icons';
import { Button, Card, Col, Divider, Row, Typography } from 'antd';
// import QRCode from 'qrcode.react';
import EnrollImage1 from '@/assets/home/enroll-01.png';
import EnrollImage2 from '@/assets/home/enroll-02.png';
import IconQrcode from '@/assets/icon-qrcode.jpg';
import { downloadFileByUrl } from '@/utils/common';
import { useCallback } from 'react';

const { Title, Paragraph, Text } = Typography;

export const HomeEnrollFileList2025 = [
  {
    name: '2025年大赛报名表',
    icon: EnrollImage1,
    fileUrl:
      'https://waterdroptest2.oss-cn-hangzhou.aliyuncs.com/NBHRXH/Assets/2025%E5%B9%B4%E5%A4%A7%E8%B5%9B%E6%8A%A5%E5%90%8D%E8%A1%A8.doc',
  },
  {
    name: '2025年大赛商业计划书模板',
    icon: EnrollImage2,
    fileUrl:
      'https://waterdroptest2.oss-cn-hangzhou.aliyuncs.com/NBHRXH/Assets/2025%E5%B9%B4%E5%A4%A7%E8%B5%9B%E5%95%86%E4%B8%9A%E8%AE%A1%E5%88%92%E4%B9%A6%E6%A8%A1%E6%9D%BF.docx',
  },
];

const FooterComponent = () => {
  return (
    <Row gutter={48} justify="center" style={{ paddingTop: 64 }}>
      {/* 联系信息 */}
      <Col xs={24} sm={12} md={8} lg={6}>
        <Title level={4} style={{ marginBottom: 24 }}>
          联系我们
        </Title>
        <div className="contact-item">
          <PhoneOutlined style={{ fontSize: 18, marginRight: 12 }} />
          <Text style={{ fontSize: 16 }}>0574-83867368,0574-83867307</Text>
        </div>
        <div className="contact-item">
          <MailOutlined style={{ fontSize: 18, marginRight: 12 }} />
          <Text style={{ fontSize: 16 }}>nb-cyds@cnnbhr.com</Text>
        </div>
        <div className="contact-item">
          <GlobalOutlined style={{ fontSize: 18, marginRight: 12 }} />
          <Text style={{ fontSize: 16 }}>www.cnnbhr.com</Text>
        </div>
      </Col>

      {/* 二维码 */}
      <Col xs={24} sm={12} md={8} lg={6}>
        <Title level={4} style={{ marginBottom: 24 }}>
          扫码关注
        </Title>
        <Card
          style={{
            width: 160,
            height: 160,
            textAlign: 'center',
            boxShadow: '0 2px 8px rgba(0, 0, 0, 0.09)',
            margin: '0 auto',
          }}
          bodyStyle={{
            padding: 0,
          }}
        >
          {/* <QRCode value="https://www.example.com" size={120} /> */}
          <img src={IconQrcode} style={{ width: '100%', height: '100%' }} />
        </Card>
      </Col>
    </Row>
  );
};

export function FooterApply() {
  const handleDownload = useCallback((fileUrl) => {
    downloadFileByUrl(fileUrl);
  });

  return (
    <Row
      gutter={48}
      justify="center"
      style={{ paddingTop: 64, maxWidth: 1200, margin: '0 auto' }}
    >
      {HomeEnrollFileList2025.map((item, index) => (
        <Col xs={24} sm={12} md={12} lg={12} key={item.fileUrl}>
          <div className="enroll-item">
            <div className="enroll-icon">
              <img src={item.icon} />
            </div>
            <div className="enroll-info">
              <h4 className="enroll-title ellipsis">{item.name}</h4>
              <Button
                type="primary"
                class="download-btn"
                onClick={() => handleDownload(item.fileUrl, item.name)}
              >
                点击下载
              </Button>
            </div>
          </div>
        </Col>
      ))}
    </Row>
  );
}

export default FooterComponent;
